@@ -73,8 +73,11 @@ def create_project():
     # Clean up pyc files.
     for (root, dirs, files) in os.walk(project_path, False):
         for f in files:
-            if f.endswith(".pyc"):
-                os.remove(os.path.join(root, f))
+            try:
+                if f.endswith(".pyc"):
+                    os.remove(os.path.join(root, f))
+            except:
+                pass
 
 if __name__ == "__main__":
     create_project()
