@@ -13,6 +13,7 @@ from mezzanine.pages.models import Page
 from mezzanine.conf import settings
 from mezzanine.utils.models import get_user_model
 
+
 User = get_user_model()
 
 
@@ -55,7 +56,7 @@ class PostsRSS(Feed):
         return self._description
 
     def link(self):
-        return reverse("blog_post_feed", kwargs={"format": "rss"})
+        return reverse("blog_post_list")
 
     def items(self):
         if not self._public:
@@ -106,6 +107,3 @@ class PostsAtom(PostsRSS):
 
     def subtitle(self):
         return self.description()
-
-    def link(self):
-        return reverse("blog_post_feed", kwargs={"format": "atom"})
