@@ -1,6 +1,8 @@
 
+import os
+
 from django.conf import settings
-from django.core.management.commands.runserver import Command as Runserver
+from django.contrib.staticfiles.management.commands import runserver
 from django.contrib.staticfiles.handlers import StaticFilesHandler
 from django.views.static import serve
 
@@ -9,12 +11,12 @@ class MezzStaticFilesHandler(StaticFilesHandler):
 
     def get_response(self, request):
         if request.path.startswith(settings.MEDIA_URL):
-            path = self.file_path(request.path)
+            path = self.file_path(request.path).replace(os.sep, "/")
             return serve(request, path, document_root=settings.STATIC_ROOT)
         return super(MezzStaticFilesHandler, self).get_response(request)
 
 
-class Command(Runserver):
+class Command(runserver.Command):
     """
     Overrides runserver so that we can serve uploaded files
     during development, and not require every single developer on
@@ -25,6 +27,6 @@ class Command(Runserver):
 
     def get_handler(self, *args, **options):
         handler = super(Command, self).get_handler(*args, **options)
-        if settings.DEBUG:
-            return MezzStaticFilesHandler(handler)
+        if settings.DEBUG or options["insecure_serving"]:
+            handler = MezzStaticFilesHandler(handler)
         return handler
