@@ -15,12 +15,13 @@ from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.contrib.sites.models import Site
 from django.core.files import File
 from django.core.files.storage import default_storage
-from django.core.urlresolvers import reverse, NoReverseMatch
+from django.core.urlresolvers import reverse, resolve, NoReverseMatch
 from django.db.models import Model, get_model
 from django.template import (Context, Node, TextNode, Template,
     TemplateSyntaxError, TOKEN_TEXT, TOKEN_VAR, TOKEN_COMMENT, TOKEN_BLOCK)
 from django.template.defaultfilters import escape
 from django.template.loader import get_template
+from django.utils import translation
 from django.utils.html import strip_tags
 from django.utils.text import capfirst
 
@@ -557,7 +558,7 @@ def admin_app_list(request):
         })
 
     app_list = list(app_dict.values())
-    sort = lambda x: x["name"] if x["index"] is None else x["index"]
+    sort = lambda x: (x["index"] if x["index"] is not None else 999, x["name"])
     for app in app_list:
         app["models"].sort(key=sort)
     app_list.sort(key=sort)
@@ -612,3 +613,28 @@ def dashboard_column(context, token):
         t = Template("{%% load %s %%}{%% %s %%}" % tuple(tag.split(".")))
         output.append(t.render(Context(context)))
     return "".join(output)
+
+
+@register.simple_tag(takes_context=True)
+def translate_url(context, language):
+    """
+    Translates the current URL for the given language code, eg:
+
+        {% translate_url de %}
+    """
+    try:
+        request = context["request"]
+    except KeyError:
+        return ""
+    view = resolve(request.path)
+    current_language = translation.get_language()
+    translation.activate(language)
+    try:
+        url = reverse(view.url_name, args=view.args, kwargs=view.kwargs)
+    except NoReverseMatch:
+        url_name = "admin:" + view.url_name
+        url = reverse(url_name, args=view.args, kwargs=view.kwargs)
+    translation.activate(current_language)
+    if context['request'].META["QUERY_STRING"]:
+        url += "?" + context['request'].META["QUERY_STRING"]
+    return url
