@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+from future.builtins import int, str
 
 from collections import defaultdict
 
